
# frozen_string_literal: true

#
# Cookbook Name:: terraform
# Recipe:: default
#
# Copyright 2014, Ross Timson
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

include_recipe "#{cookbook_name}::gpgme"

log "#{checksums_file} trust worthiness alert" do
  message "#{checksums_file} file cannot be trusted: gpg signature rejected"
  level :error
  notifies :delete, "remote_file[#{checksums_file}]", :immediately
  notifies :run, 'ruby_block[raise if signature file cannot be trusted]',
           :immediately
  not_if { signatures_trustworthy? }
end

ruby_block 'raise if signature file cannot be trusted' do
  block do
    raise "GPG signature of #{checksums_file} not valid"
  end
  action :nothing
  not_if { signatures_trustworthy? }
end

node.default['terraform']['checksums'] = raw_checksums_to_hash
node.default['terraform']['checksum'] = raw_checksums_to_hash[terraform_zipfile]

include_recipe 'ark'

ark 'terraform' do
  url terraform_url
  version node['terraform']['version']
  checksum node['terraform']['checksum']
  has_binaries ['terraform']
  append_env_path false
  strip_components 0

  if platform_family?('windows')
    win_install_dir node['terraform']['win_install_dir']
    owner node['terraform']['owner']
  end

  action :install
end

# update path
windows_path 'Windows install directory' do
  unless node['terraform']['win_install_dir'].nil?
    path node['terraform']['win_install_dir']
  end
  action :add
  only_if { platform_family?('windows') }
end
